@@ -44,6 +44,3 @@ class DirichletMultinomial:
         if l > u:
             return 0.0
         return self.cdf(weights, l) - self.cdf(weights, u)
-
-    def sample(self, n):
-        raise NotImplementedError()
